@@ -80,34 +80,44 @@ def check_add_lemmas(add_lemmas=True,**kwargs):
         return new_map
     else:
         return LEMMA_MAP
+    
+def add_feature_to_lemma_map(lemma_map,feature_name,**kwargs):
+    for key,val in lemma_map.items():
+        val[feature_name] = ({},{})
+    _save_map(lemma_map,**kwargs)
 
 # =============================================================================
 # Features 
 # =============================================================================
-FEATURES = ['present','future',
-            'verb_poss','verb_cert',
-            'adv_adj_poss','adv_adj_cert',
-            'mental_poss','mental_cert',
-            'particle_poss','particle',
-            'will_future','go_future']
-
 LANGUAGES = ['english','dutch','german']
 
-EXTRA_FEATURES = ['negated','lexi_poss',
-                  'lexi_cert','future_dom',
-                  'present_dom','go_future_dom',
-                  'will_future_dom','no_code']
+SUBMISSIVE_FEATURES = ['present','future','will_future','go_future']
+
+DOMINANT_FEATURES = ['verb_poss','verb_cert',
+                     'adv_adj_poss','adv_adj_cert',
+                     'mental_poss','mental_cert',
+                     'particle_poss','particle','particle_cert']
+
+DOMINATED_FEATURES = ['future_dom','present_dom',
+                     'go_future_dom','will_future_dom']
+
+SUMMARY_FEATURES = ['lexi_poss','lexi_cert']
+
+EXTRA_FEATURES = ['negated','no_code']
 
 MAIN_FEATURES = ['lexi_poss','lexi_cert','future_dom',
                   'present_dom','verb_poss','verb_cert']
 
-ALL_FEATURES = FEATURES + EXTRA_FEATURES
+FEATURES = DOMINANT_FEATURES + SUBMISSIVE_FEATURES
+ALL_FEATURES = FEATURES + DOMINATED_FEATURES + SUMMARY_FEATURES + EXTRA_FEATURES
 # =============================================================================
 # English word lists
 # =============================================================================
-english = {'present':([],
+english = {'present':([' i s ',
+                       ' im '],#typos
                       ["'m",
                        "'re",
+                       "'s",
                        'allow',
                        'allows',
                        'am',
@@ -206,12 +216,12 @@ english = {'present':([],
                        'works']
                           ),
     
-    'future':(['about to','is going','are going','am going','going to'],
+    'future':(['about to','is going','are going','am going','going to','theyll'],
               ['will',
                'wil',
                'shall',
                "'ll",
-               "theyll"]
+               "ll"]
             ),
     
     'verb_poss':([],
@@ -220,8 +230,9 @@ english = {'present':([],
                   'could',
                   'might',
                   'should',
-                  'sould',
-                  'ought'
+                  'sould',#typo
+                  'ought',
+                  'would'#used epistemically in the 'what your brother would do... question, i.e. as a conditional 
                   ]
                  ),
     
@@ -325,14 +336,19 @@ english = {'present':([],
     'particle_poss':([],
                      []
                      ),
+    
+    'particle_cert':([],
+                     []
+                     ),
     'particle':([],
                 []
                 ),
-    'will_future':([],
+    
+    'will_future':(['theyll'],
                    ['will',
                     'wil',
                     "'ll",
-                    "theyll"]
+                    "ll"]
                    ),
     'go_future':(['is going','are going',
                    'am going','going to'],
@@ -350,8 +366,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'ze halen het','val om','stort in',
                      'valt om','storten in','storten inen',
                      'kom an','komt an','komen an','knap op',
+                     'kom ik',
                      'knapt op','knappen op','uit eten','uit eet',
-                     'kom op','komt op','komen op',
+                     'kom op','komt op','komen op','ik ik',#typo
                      'zwel op','zwelt op','zwellen op'],
                     ['.is',#typo
                      'accepteer',
@@ -401,6 +418,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'heb',
                      'hebben',
                      'hebt',
+                     'hen',#heb typo
                      'heeft',
                      'helen',
                      'heel',
@@ -426,6 +444,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'krijgt',
                      'laat',
                      'laten',
+                     'latten',#typo
                      'maak',
                      'maaken',
                      'maakt',
@@ -442,6 +461,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'reis',
                      'reist',
                      'reizen',
+                     'resit',#misspelled
                      'resideer',
                      'resideert',
                      'resideren',
@@ -495,6 +515,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'verslijt',
                      'verslijten',
                      'verslitjen',
+                     'verlijten',#common typo
                      'verspil',
                      'verspillen',
                      'verspilt',
@@ -520,6 +541,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'woon',
                      'woont',
                      'wwon',#typo 
+                     'word',#could indicate future marking, but sentences in frames use  it not as such (i.e. I become fat...)
+                     'worden',
+                     'wordt',
                      'zie',
                      'zien',
                      'ziet',
@@ -530,17 +554,22 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'zitten',
                      'zwel',
                      'zwellen',
-                     'zwelt']
+                     'zwelt',
+                     'zeg', #say, and though can be used as mental state pred use (Nuyts, 2000), it is not in our frames, i.e. "I {SAY} no this time..."
+                     'zeggen',
+                     'zegt']
                     ),
     
           'future':(['staat op'],#about to
                    ['ga',
-                    'gaat', 
+                    'gaat',
+                    'gat',#common typo
                     'gaan',
                     'zal', 
                     'zullen',
                     'zult', 
                     'zul',
+                    'economie.zal',#typo
                     'gaanverliezen'] #misspelling of gaan verleizen, "going to lose"
                    ),
         'verb_poss':([],
@@ -554,7 +583,10 @@ dutch = {'present':(['is het','vallen om','storten in',
                       'mag',
                       'mogen', #doesn't have primary epistemic uses, more deontic, Nuyts 2000, but included anyway for exploratory pusposes 
                       'vermogen',
-                      'vermoogd'] #i.e. mogen + prefix ver-
+                      'vermoogd',
+                      'zou',#past tense form of zullen, translated as 'should'/indicates epistemic modality in Broekhuis (2014) + coders/informants agree 
+                      'zouden'
+                      ] #i.e. mogen + prefix ver-
                      ),
         'verb_cert':([],
                      ['moeten',
@@ -593,11 +625,12 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'verwacht',
                          'waarschijnlijk',
                          'wellicht',#probably
-                         'word',
-                         'worden',
-                         'wordt']#unclear worden "becomes" is a futuroid, but is in the present tense. from a cognitive/pragmatic perspective, it is somewhat modal/marked
+                         ]
                         ),
-        'adv_adj_cert':(['wel degelijk'],
+        'adv_adj_cert':(['wel degelijk',
+                         '100%',#expresses certainty in some responses
+                         'twijfel er niet',#no doubt
+                         'zoals altijd'], #as always, implied certainty (informant/personal communication)
                         ['absoluut',
                          'alleszins',
                          'allicht',
@@ -675,10 +708,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'annehm',#to assume, but more clear qualificational use than in English (Nuyts 2000)
                          'annehmt',
                          'annehmen',
-                         'zeg', #say, but similar to mental state pred use (Nuyts, 2000)
-                         'zeggen',
-                         'zegt',
-                         
+                         #'zeg', #say, and though can be used as mental state pred use (Nuyts, 2000), it is not in our frames
+                         #'zeggen',
+                         #'zegt',                         
                          ]
                         ),
         'mental_cert':([],
@@ -688,6 +720,11 @@ dutch = {'present':(['is het','vallen om','storten in',
         'particle_poss':(['wel eens'],
                          ['wel']
                          ),
+        
+        'particle_cert':([],
+                         ['toch'] #indicates certainty according to coders, informants
+                         ),
+        
         'particle':(['nou eenmaal',
                      'nu eenmaal'],
                     ['eens'
@@ -700,20 +737,22 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'ja',
                      'maar',
                      'nou'
-                     'nu',
-                     'toch']
+                     'nu']
                     ),
         'will_future':([],
                        ['zal', 
                         'zult',
                         'zul',
-                        'zullen']
+                        'zullen',
+                        'economie.zal'#typo
+                        ]
                        ),
         'go_future':([],
                      ['ga',
                       'gaat',
                       'gaan',
-                      'gaanverliezen']
+                      'gat',#typo
+                      'gaanverliezen']#typo
                      )
         }
 
@@ -738,7 +777,12 @@ german = {'present':(['nutze ab',
                       'gehe auf',
                       'gehst auf',
                       'geht auf',
-                      'gehen auf'],
+                      'gehen auf',
+                      'breche zusammen',
+                      'brichst zusammen',
+                      'bricht zusammen',
+                      'brechen zusammen',
+                      'brecht zusammen'],
                      ['bin',
                       'bist', 
                       'ist', 
@@ -813,14 +857,18 @@ german = {'present':(['nutze ab',
                       'lebe', 
                       'lebst', 
                       'lebt', 
-                      'leben']),
+                      'leben',
+                       ]),
     'future': ([],
                ['werde',
                 'wirst',
                 'wird',
                 'werden',
                 'werdet',
-                'werden']),
+                'werden',
+                'wirdt'#typo
+                ]
+               ),
     'verb_poss':([],
                  [#indicative of können
                   'kann',
@@ -870,6 +918,12 @@ german = {'present':(['nutze ab',
                   #'möchten',
                   #'möchtet',
                   
+                  ##konjuntiv of werden, i.e. 'would' with epistemic uses: according to informant/coder
+                  'würde',
+                  'würdest',
+                  'würden',
+                  'würdet',
+                  
                   #konjunktiv ii of müssen has epistemic uses, like 'should' (Mortelmans 2000).
                   'müßte',
                   'müßtest',
@@ -897,6 +951,7 @@ german = {'present':(['nutze ab',
                      'eventuell',
                      'anscheinend',
                      'gegebenenfalls',
+                     'wahrscheinlichkeit',#probability -- informant coder
                      'möglich',
                      'möglicherweise',
                      'offenbar',
@@ -951,10 +1006,14 @@ german = {'present':(['nutze ab',
                     'rechnest',
                     'rechnet',
                     'rechnen',
-                    'sage',
-                    'sagst',
-                    'sagt',
-                    'sagen',
+                    #'sage',#while this can be used epistemically, none of the question frames do so
+                    #'sagst',# and do use 'to say' in non epistemic ways
+                    #'sagt',
+                    #'sagen',
+                    'erwarte', #expect -- very little reference to it... but human coders/informants indicate it indicates possibility/uncertainty
+                    'erwartest',
+                    'erwartet',
+                    'erwarten'
                     ]
                     ),
     
@@ -968,6 +1027,11 @@ german = {'present':(['nutze ab',
     'particle_poss':([],
                      ['wohl']
                       ),
+    
+    'particle_cert':([],
+                     []
+                     ),
+    
     'particle':([],
                  ['aber',
                   'auch',
@@ -1015,6 +1079,6 @@ LEMMA_MAP = _load_map()
 
 #run and save changes to lemma map
 if __name__ == '__main__':
-    #LEMMA_MAP = check_add_lemmas()
-    pass
+    LEMMA_MAP = check_add_lemmas()
+    #pass
     
